package org.gnugk;

/**
 * The Alias class represents basic data about an H.323 alias.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.1
 */

public class Alias {
    // the states an endpoint can be in
    public final static int AVAILABLE = 0;
    public final static int TALKING = 1;

    private String alias;
    private String epid;    // endpoint on wich this alias is registered
    private int state;      // current state
    private String crv;     // CRV value, if the Alias is TALKING

    /**
     * Initialize the Alias object.
     * @param _alias    H.323 alias
     * @param _epid     endpoint ID
     */
    public Alias(String _alias, String _epid) {
        alias = _alias;
        epid = _epid;
        state = AVAILABLE;
        crv = "";
    }

    /**
     * Make sure aliases are compared by alias name and endpoint ID.
     * @param o alias to compare with
     * @return      T / F
     */
    public boolean equals(Object o) {
        Alias other = (Alias)o;
        return this.getAlias().equals(other.getAlias()) &&
               this.getEpid().equals(other.getEpid());
    }

    /**
     * Create unique hash code.
     * @return hash code
     */
    public int hashCode() {
        return (epid + alias).hashCode();
    }

    /**
     * Access the alias.
     * @return  H.323 alias
     */
    public String getAlias() {
        return alias;
    }

    /**
     * Access to endpoint ID.
     * @return  endpoint ID
     */
    public String getEpid() {
        return epid;
    }

    /**
     * Access the alias state.
     * @return  alias state (see constants)
     */
    public int getState() {
        return state;
    }

    /**
     * Change the alias state.
     * @param _state new state (see constants)
     */
    public void setState(int _state) {
        state = _state;
    }

    /**
     * Access the CRV for a TALKING alias.
     * @return  CRV
     */
    public String getCrv() {
        return crv;
    }

    /**
     * Change the CRV for a TALKING alias.
     * @param _crv new CRV
     */
    public void setCrv(String _crv) {
        crv = _crv;
    }

    /**
     * Printable representation.
     * @return  string
     */
    public String toString() {
        return getAlias() + "(" + getEpid() + ")";
    }

}
