// This work is published under the GNU Public License (GPL)
// see file COPYING for details.

package org.gnugk;

/**
 * The Endpoint class represents basic data about endpoints.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.1
 */

public class Endpoint
{
	// the states an endpoint can be in
	public final static int AVAILABLE = 0;
	public final static int TALKING = 1;

	private String epid;
	private String alias;
    private int state;

    /**
     * Initialize the Endpoint object.
     * @param _epid     endpoint ID
     * @param _alias    first H.323 alias
     */
	public Endpoint(String _epid, String _alias)
	{
		epid = _epid;
		alias = _alias;
        state = AVAILABLE;
	}

    /**
     * make sure endpoints are compared only by endpoint ID.
     * @param other endpoint to compare with
     * @return      T / F
     */
    public boolean equals(Object other) {
        return this.getEpid().equals(((Endpoint)other).getEpid());
    }

    /**
     * Return hash code of unique identifier.
     * @return  hash code
     */
    public int hashCode() {
        return epid.hashCode();
    }

    /**
     * Access to endpoint ID.
     * @return  endpoint ID
     */
    public String getEpid() {
        return epid;
    }

    /**
     * Change the endpoint ID. Rarely usefull!
     * @param epid  new endpoint ID
     */
    public void setEpid(String epid) {
        this.epid = epid;
    }

    /**
     * Access the first alias.
     * @return  H.323 alias
     */
    public String getAlias() {
        return alias;
    }

    /**
     * Change the endpoint alias.
     * @param alias H.323 alias
     */
    public void setAlias(String alias) {
        this.alias = alias;
    }

    /**
     * Access the endpoint state.
     * @return  endpoint state (see constants)
     */
    public int getState() {
        return state;
    }

    /**
     * Change the endpoint state.
     * @param state new state (see constants)
     */
    public void setState(int state) {
        this.state = state;
    }

    /**
     * Printable representation.
     * @return  string
     */
    public String toString() {
        return getAlias() + "(" + getEpid() + ")";
    }
}
