// This work is published under the GNU Public License (GPL)
// see file COPYING for details.

package org.gnugk;

/**
 * Interface for storing endpoint data.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */

public interface EndpointStorage {

    /**
     * Add endpoint.
     * @param _epid     endpoint ID
     * @param _alias    first H.323 alias
     */
    public void addEndpoint(String _epid, String _alias);

    /**
     * Remove endpoint.
     * @param _epid     endpoint ID
     */
    public void removeEndpoint(String _epid);

    /**
     * Change endpoint state.
     * @param _epid     endpoint ID
     * @param _state    new state
     */
    public void setEndpointState(String _epid, int _state);

    /**
     * Access endpoint by endpoint ID.
     * @param _epid     endpoint ID
     * @return          the endpoint
     */
    public Endpoint endpointById(String _epid);

    /**
     * Access endpoint by alias.
     * @param _alias    H.323 alias
     * @return          the endpoint
     */
    public Endpoint endpointByAlias(String _alias);

}
