// This work is published under the GNU Public License (GPL)
// see file COPYING for details.

package org.gnugk;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * Superclass for easy handling of config files.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
public class GnuGkAppConfig {
    /**
     * The application config.
     */
    protected ResourceBundle config;

    /**
     * Load the config file.
     * @param name  basename to be search on classpatch (eg. XYApp.properties)
     */
    protected void readConfig(String name) {
        try {
            config = ResourceBundle.getBundle(name);
        } catch (MissingResourceException e) {
            System.out.println("Can find config file: Place " + name + ".properties on CLASSPATH !");
            System.exit(-1);
        }
    }

    /**
     * Get a config setting as string.
     * @param configKey     config key
     * @param defaultValue  default value, if key is not found
     * @return              the config setting
     */
    public String getConfigKey(String configKey, String defaultValue) {
        try {
            return config.getString(configKey);
        } catch (MissingResourceException e) {
            // ignore: will return default
        }
        return defaultValue;
    }

    /**
     * Get a config setting as integer.
     * @param configKey     config key
     * @param defaultValue  default value, if key is not found
     * @return              the config setting
     */
    public int getConfigKey(String configKey, int defaultValue) {
        try {
            return Integer.parseInt(config.getString(configKey));
        } catch (MissingResourceException e) { // ignore: return default
        } catch (NumberFormatException e) { // ignore: return default
        }
        return defaultValue;
    }
}
