// This work is published under the GNU Public License (GPL)
// see file COPYING for details.

package org.gnugk;

import java.io.OutputStream;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;

/**
 * The Logger class controlls log and debug output.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
public final class Logger {
    private static int debug = 0;
    private static OutputStream output = System.out;

    /**
     * Set debug level.
     * @param debug new debug level
     */
    public static void setDebug(int debug) {
        Logger.debug = debug;
    }

    /**
     * Set file where to send the output, default is the console.
     * @param filename   filename
     */
    public static void setLogfile(String filename) {
        try {
            output = new FileOutputStream(filename);
        } catch (FileNotFoundException e) {
            output = System.out;
            Logger.println("Can't open output file: " + filename);
        }
    }

    /**
     * Print normal logging output.
     * @param msg   message
     */
    public static void log (String msg) {
            Logger.println(msg);
    }

    /**
     * Print debug output, if running in debug mode.
     * @param msg   message
     */
    public static void debug(String msg) {
        if (debug > 0)
            Logger.println("DEBUG: " + msg);
    }

    private static void println(String msg) {
        try {
            output.write((msg + "\n").getBytes());
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

}
