// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import java.net.ServerSocket;
import java.io.IOException;

/**
 * Listen for commands for the ACD (eg. agent login / logout).
 * The actual work is done by the threads forked for each client connection.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
class ACDCommandListener implements Runnable {
    private int port;
    private String redirLocation;
    private volatile boolean listening = true;
    private ServerSocket listenSocket = null;

    /**
     * Initialize the thread before it can be run().
     * @param _port     listen port
     * @param _location location where the listener threads redirect after a command
     */
    public void init(int _port, String _location) {
        port = _port;
        redirLocation = _location;
    }

    /**
     * Listen for new connections and start a worker thread for each connection.
     */
    public void run() {

        try {
            listenSocket = new ServerSocket(port);
        } catch (IOException ioe) {
            System.out.println("Can't open listen socket on port " + port + ":" + ioe);
            System.exit(-1);
        }

        while (listening) {
            try {
                new Thread(new ACDCommandListenerThread(listenSocket.accept(), redirLocation)).start();
            } catch (IOException ioe) {
                if (listening)
                    ioe.printStackTrace();
                // else ignore, exception is normal on shutdown to terminate accept()
            }
        }
        try {
            listenSocket.close();
        } catch (IOException ioe) {
            // ignore, we want to shut down
        }
    }

    /**
     * Stop the thread.
     */
    public void stopListening() {
        listening = false;
        // wakeup accept
        Thread.currentThread().interrupt();
    }

}
