// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import org.gnugk.Logger;

import java.net.Socket;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * Thread to handle one client that send commands to the ACD.
 * Uses HTTP protocol, so you can point your browser at it.
 * Example: http://localhost:7001/logout?frank
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
class ACDCommandListenerThread implements Runnable {
    private final static String HTTP_OK = "HTTP/1.0 200 OK\n";
    private final static String HTTP_REDIR = "HTTP/1.0 302 Moved Temporarily\n";
    private final static String HTTP_NOCACHE = "Cache-Control: no-cache\nPragma: no-cache\nExpires: -1\n";
    private final static String HTTP_TEXT = "Content-Type: text/plain\n";
    private final static String HTTP_END = "\n";
    private Socket socket;
    private String location;

    /**
     * Initialize the worker thread.
     * @param socket    connection to handle
     * @param redirLocation where to redirect after command
     */
    public ACDCommandListenerThread(Socket socket, String redirLocation) {
        this.socket = socket;
        this.location = redirLocation;
    }

    public void run() {
        GnuGkACD acd = GnuGkACD.getInstance();

        try {
            BufferedReader in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            PrintWriter out = new PrintWriter(socket.getOutputStream(), true);
            String inputLine = in.readLine();
            if (inputLine != null) {
                Logger.debug("HTTP:" + inputLine);
                // handle commands
                if (inputLine.startsWith("GET /logout") || inputLine.startsWith("GET /logoff") ) {
                    String agent = inputLine.substring(12);
                    if (agent.indexOf(" ") > 0) {
                        agent = agent.substring(0, agent.indexOf(" "));
                    }
                    Logger.debug("Command accepted: Logout " + agent);
                    acd.logout(agent);
                    out.println (HTTP_REDIR + "Location: " + location + "\n\n");
                }
                else if (inputLine.startsWith("GET /login")) {
                    String agent = inputLine.substring(11);
                    if (agent.indexOf(" ") > 0) {
                        agent = agent.substring(0, agent.indexOf(" "));
                    }
                    Logger.debug("Command accepted: Login " + agent);
                    acd.login(agent);
                    out.println (HTTP_REDIR + "Location: " + location + "\n\n");
                }
                else if (inputLine.startsWith("GET /status")) {
                    Logger.debug("Command accepted: Status");
                    out.println (HTTP_OK + HTTP_NOCACHE + HTTP_TEXT + HTTP_END +
                            acd.dumpAgentStates() + "\n\n" +
                            acd.dumpPendingList());
                }
                else {
                    out.println (HTTP_OK + HTTP_NOCACHE + HTTP_TEXT + HTTP_END +
                            "Unknown command\n\n");
                }
            }
            out.close();
            in.close();
            socket.close();
        } catch (IOException ioe) {
            // ignore
        }
    }
}
