// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import org.gnugk.CallRouter;

/**
 * This class activates house keeping activities such as expiring requests etc.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
class HouseKeeper implements Runnable {
    private final static int DEFAULT_SANITY_INTERVAL = -1;   // in sec
    private int sanityInterval;
    private volatile boolean running = true;
    private CallRouter router;
    private CallBacklog backlog;

    /**
     * Initialize thread.
     * @param _backlog  Backlog of calls to keep clean
     */
    public void init(CallRouter _router, CallBacklog _backlog) {
        router = _router;
        backlog = _backlog;
        sanityInterval = ACDConfig.getInstance().getConfigKey("sanity_interval", DEFAULT_SANITY_INTERVAL);
    }

    /**
     * Run the thread.
     */
    public void run() {
        long lastSanityCheck = System.currentTimeMillis();
        while(running) {
            // do the work
            backlog.expire();   // expire old requests every second

            if ( (sanityInterval > 0) &&
                 (System.currentTimeMillis() > lastSanityCheck + (sanityInterval * 1000))) {
                router.agentSanityCheck();
                lastSanityCheck = System.currentTimeMillis();
            }

            // sleep
            try {
                Thread.sleep(1 * 1000); // sleep 1 sec.
            } catch (InterruptedException e) { /* ignore */ }
        }
    }

}
