// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

/**
 * This class stores a pending RouteRequest.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
class PendingRequest implements Comparable {
    public static final int RINGING = 1;
    public static final int TALKING = 2;

    public int priority;
    public String queue;
    public String callerEndId;
    public String callRef;
    public String callerAlias;
    public String callerIp;
    public int status;
    public long timeout;

    /**
     * Create a new request object.
     * @param _priority
     * @param _queue
     * @param _callerEndId
     * @param _callRef
     * @param _callerAlias
     * @param _callerIp
     * @param _timeout
     * @param _status   Ringing / Talking
     */
    public PendingRequest(int _priority, String _queue, String _callerEndId, String _callRef, String _callerAlias, String _callerIp, long _timeout, int _status) {
        priority = _priority;
        queue = _queue;
        callerEndId = _callerEndId;
        callRef = _callRef;
        callerAlias = _callerAlias;
        callerIp = _callerIp;
        timeout = _timeout;
        status = _status;
    }

    /**
     * Sort requests by queue priority and expire time.
     * @param o     Object to compare to
     * @return      -1 / 0 / 1
     */
    public int compareTo(Object o) {
        PendingRequest r2 = ((PendingRequest)o);
        if (priority < r2.priority)
            return 1;
        if (priority > r2.priority)
            return -1;
        if (timeout < r2.timeout)
            return -1;
        if (timeout > r2.timeout)
            return 1;
        if (callerEndId.compareTo(r2.callerEndId) < 0)
            return -1;
        if (callerEndId.compareTo(r2.callerEndId) > 0)
            return 1;
        return callRef.compareTo(r2.callRef);
    }

    /**
     * Requests are equal if endpoint ID and callRef match.
     * @param o Object to compare to
     * @return  T / F
     */
    public boolean equals(Object o) {
        PendingRequest r2 = ((PendingRequest)o);
        return (callerEndId.equals(r2.callerEndId) && callRef.equals(r2.callRef));
    }

    /**
     * Implement hashCode, based on what makes the object uniqe.
     * @return  hash code
     */
    public int hashCode() {
        return (callerEndId + callRef).hashCode();
    }
}
