// This work is published under the GNU Public License (GPL)
// see file COPYING for details.
//
// The initial creation of this ACD application has been
// sponsored by IPTEL Inc. www.iptel.com.
//
// Author: Jan Willamowius <jan@willamowius.de>

package org.gnugk.acd;

import org.gnugk.Logger;
import org.gnugk.GkClient;
import org.gnugk.acd.ACDConfig;

import java.io.IOException;
//import java.io.InputStreamReader;
//import java.io.BufferedReader;
import java.util.Vector;

/**
 * This class manages the stating and stopping of talking wait queues.
 *
 * @author Jan Willamowius <jan@willamowius.de>
 * @version 1.0
 */
public class WQManager extends Thread {
    private final static int KILL_SLEEP = 3;    // sleep 3 sec after killing WQs, before unregister
    private final static int DEFAULT_PORTRANGE = 1730;  // default for portrange start

    private static Vector processList = new Vector();
    private GkClient gk;

    private class WQProcess {
        public String alias;
        public Process p;
        public WQProcess(String _alias, Process _p) { alias = _alias; p = _p; };
    }

    public void startWaitQueues(GkClient _gk) {
        ACDConfig config = ACDConfig.getInstance();
        String startCmd = config.getConfigKey("wq_start_cmd", "");
        int port = config.getConfigKey("wq_portrange_start", DEFAULT_PORTRANGE);

        gk = _gk;

        if (startCmd.length() <= 0)
            return;     // don't start talking agents

        // register a hook so we can clean up on shutdown
        Runtime.getRuntime().addShutdownHook(this);

        String[] queues = config.getQueues();
        for (int q=0; q < queues.length; q++) {
            String queue = queues[q];
            int mode = config.getQueueingMode(queue);
            if ((mode == ACDConfig.QUEUEING_MODE_TALKING) || (mode == ACDConfig.QUEUEING_MODE_RINGANDTALK)) {
                int numAgents = config.getMaxSize(queue);
                Logger.log("Starting " + numAgents + " talking wait queues for " + queue);
                String messageFile = config.getConfigKey(queue + "_wq_message", "");
                for (int i=1; i <= numAgents; i++) {
                    String alias = queue + "_wq_" + i;
                    String execCmd = startCmd;
                    execCmd = execCmd.replaceAll("%P", new Integer(port).toString());
                    execCmd = execCmd.replaceAll("%A", alias);
                    execCmd = execCmd.replaceAll("%W", messageFile);
                    try {
                        Logger.debug("Forking " + execCmd);
                        Process p = Runtime.getRuntime().exec(execCmd);
                        processList.add(new WQProcess(alias, p));
//                        // DEBUG: catch STDOUT from new process
//                        BufferedReader is = new BufferedReader(new InputStreamReader(p.getInputStream()));
//                        String line;
//                        while ((line = is.readLine()) != null)
//                            System.out.println(line);
                    } catch (IOException e) {
                        Logger.log("Start of " + alias + " failed.");
                    }
                    // increment listenport
                    port++;
                }
            }
        }
    }

    public void run() {
        if (processList.size() > 0) {
            Logger.log("Stopping talking wait queues");
            for(int i = 0; i < processList.size(); i++ ) {
                WQProcess wq = (WQProcess) processList.elementAt(i);
                wq.p.destroy();    // terminates the process
            }
            try {
                Thread.sleep(KILL_SLEEP * 1000);     // wait 3 sec
            } catch (InterruptedException e) { /* ignore */ }
            for(int i = 0; i < processList.size(); i++ ) {
                WQProcess wq = (WQProcess) processList.elementAt(i);
                // send UnregisterAlias to GnuGk
                gk.unregisterAlias(wq.alias);
            }
            processList.clear();
        }
    }

}
